# Changelog

## Unreleased Changes

## 2.35.0

- Upgrade core to v2 to stay compatible with anonymous recipients
  [#20](https://github.com/deltachat-bot/deltawoot/pull/20)
  [#21](https://github.com/deltachat-bot/deltawoot/pull/21)

## 1.3.1

- Ignore messages from other inboxes

## 1.3.0

- Add sentry support for monitoring

## 1.2.0

- Support docker compose setup
  [#12](https://github.com/deltachat-bot/deltawoot/pull/12)

- Send welcome message when user scans QR code
  [#11](https://github.com/deltachat-bot/deltawoot/pull/11)

## 1.1.0

- Store attachments in `files/attachments/`
  [#4](https://github.com/deltachat-bot/deltawoot/issues/4)

- Save downloaded files with URL-decoded filename

- Don't pass deltachat-internal info messages to chatwoot

- Display voice messages properly in chatwoot

## 1.0.0

- Release initial version

